# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ErrorEntity
from ..models import ItemReferenceInfo

from ..operations.utilities import GetItemReferences


@same_doc_as(GetItemReferences)
def get_item_references(
    item_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get season pass ecommerce item references (getItemReferences)

    This API is used to get season pass ecommerce item references.

    Other detail info:

      * Returns : item references data

    Properties:
        url: /seasonpass/admin/namespaces/{namespace}/seasons/item/references

        method: GET

        tags: ["Utilities"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        item_id: (itemId) REQUIRED str in query

    Responses:
        200: OK - ItemReferenceInfo (successful operation)

        400: Bad Request - ErrorEntity (20026: publisher namespace not allowed | 20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetItemReferences.create(
        item_id=item_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetItemReferences)
async def get_item_references_async(
    item_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get season pass ecommerce item references (getItemReferences)

    This API is used to get season pass ecommerce item references.

    Other detail info:

      * Returns : item references data

    Properties:
        url: /seasonpass/admin/namespaces/{namespace}/seasons/item/references

        method: GET

        tags: ["Utilities"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        item_id: (itemId) REQUIRED str in query

    Responses:
        200: OK - ItemReferenceInfo (successful operation)

        400: Bad Request - ErrorEntity (20026: publisher namespace not allowed | 20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetItemReferences.create(
        item_id=item_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
